aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorEddie Hung <eddie@fpgeh.com>2019-05-27 19:40:27 -0700
committerEddie Hung <eddie@fpgeh.com>2019-05-27 19:40:27 -0700
commit4df37c77fdb709e67528cf6fe1a2cf52b004c156 (patch)
tree6333559df99df18270fef8cdd5ecfa86f424e240
parent428d7c8e11db3aa4d65b0509946a47b005f87988 (diff)
downloadyosys-4df37c77fdb709e67528cf6fe1a2cf52b004c156.tar.gz
yosys-4df37c77fdb709e67528cf6fe1a2cf52b004c156.tar.bz2
yosys-4df37c77fdb709e67528cf6fe1a2cf52b004c156.zip
Disconnect all ABC boxes too
-rw-r--r--passes/techmap/abc9.cc20
1 files changed, 9 insertions, 11 deletions
diff --git a/passes/techmap/abc9.cc b/passes/techmap/abc9.cc
index a2948548d..10c795525 100644
--- a/passes/techmap/abc9.cc
+++ b/passes/techmap/abc9.cc
@@ -867,21 +867,19 @@ void abc9_module(RTLIL::Design *design, RTLIL::Module *current_module, std::stri
// module->connect(conn);
// }
// Go through all AND and NOT output connections,
// and for those output ports driving wires
// also driven by mapped_mod, disconnect them
for (auto cell : module->cells()) {
- if (!cell->type.in("$_AND_", "$_NOT_"))
- continue;
+ if (!cell->type.in("$_AND_", "$_NOT_")) {
+ RTLIL::Module* cell_module = design->module(cell->type);
+ if (!cell_module || !cell_module->attributes.count("\\abc_box_id"))
+ continue;
+ }
for (auto &it : cell->connections_) {
auto port_name = it.first;
if (!cell->output(port_name)) continue;
- auto &signal = it.second;
- auto bits = signal.bits();
- for (auto &b : bits)
- if (output_bits.count(b))
- b = module->addWire(NEW_ID);
- signal = std::move(bits);
+ it.second = RTLIL::SigSpec();
}
}
// Do the same for module connections
@@ -867,21 +867,19 @@ void abc9_module(RTLIL::Design *design, RTLIL::Module *current_module, std::stri
// module->connect(conn);
// }
- // Go through all AND and NOT output connections,
- // and for those output ports driving wires
- // also driven by mapped_mod, disconnect them
+ // Go through all AND, NOT, and ABC box instances,
+ // and disconnect their output connections in
+ // preparation for stitching mapped_mod in
for (auto cell : module->cells()) {